summaryrefslogtreecommitdiffstats
path: root/kscd/bwlednum.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 06:00:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 06:00:15 +0000
commitb1057f437bf65300831a0ccb45b920787c6b318d (patch)
treef8a73db06ca1180d0da0ba6dfbe786197b4f4bc3 /kscd/bwlednum.cpp
parent4ddfca384ced9ad654213aef9dc2c3973720b980 (diff)
downloadtdemultimedia-b1057f437bf65300831a0ccb45b920787c6b318d.tar.gz
tdemultimedia-b1057f437bf65300831a0ccb45b920787c6b318d.zip
TQt4 port kdemultimedia
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdemultimedia@1236079 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kscd/bwlednum.cpp')
-rw-r--r--kscd/bwlednum.cpp68
1 files changed, 34 insertions, 34 deletions
diff --git a/kscd/bwlednum.cpp b/kscd/bwlednum.cpp
index 4bfb16b6..fdc2beba 100644
--- a/kscd/bwlednum.cpp
+++ b/kscd/bwlednum.cpp
@@ -36,8 +36,8 @@ static char segs[14][8] =
{25, 0, 0, 0, 0, 0, 0, 0} }; // blank
-BW_LED_Number::BW_LED_Number( TQWidget *parent, const char *name )
- : TQFrame( parent, name ){
+BW_LED_Number::BW_LED_Number( TQWidget *tqparent, const char *name )
+ : TQFrame( tqparent, name ){
offcolor = TQColor(100,0,0);
@@ -84,7 +84,7 @@ void BW_LED_Number::setLEDColor( const TQColor& fgColor, const TQColor& bgColor
fgcolor = fgColor;
bgcolor = bgColor;
- TQColorGroup old_cg = this->colorGroup();
+ TQColorGroup old_cg = this->tqcolorGroup();
TQColorGroup new_cg( fgColor, bgColor,
@@ -168,9 +168,9 @@ void BW_LED_Number::setSmallLED(bool a_boolean){
}
-void BW_LED_Number::drawSymbol( TQPainter *p,char ,bool repaint ){
+void BW_LED_Number::drawSymbol( TQPainter *p,char ,bool tqrepaint ){
- // printf("drawSymbol repaint = %d\n",repaint);
+ // printf("drawSymbol tqrepaint = %d\n",tqrepaint);
TQPoint pos;
@@ -194,7 +194,7 @@ void BW_LED_Number::drawSymbol( TQPainter *p,char ,bool repaint ){
pos = TQPoint( Xoffset , Yoffset );
- if(repaint){
+ if(tqrepaint){
// this draw the non-illumintated segments
@@ -222,7 +222,7 @@ void BW_LED_Number::drawSymbol( TQPainter *p,char ,bool repaint ){
}
}
}
- else{ // we are not repainting ourselves due to a repaint event but rather
+ else{ // we are not tqrepainting ourselves due to a tqrepaint event but rather
// genuinely changing the symbol that is to be displayed
for(int l = 0; l <= NUM_OF_SEGMENTS -1; l++){
@@ -277,7 +277,7 @@ void BW_LED_Number::drawSegment( const TQPoint &pos, char seg_number, TQPainter
TQPoint pt = pos;
- TQColorGroup g = colorGroup();
+ TQColorGroup g = tqcolorGroup();
TQColor lightColor,darkColor;
if ( erase ){
@@ -297,7 +297,7 @@ void BW_LED_Number::drawSegment( const TQPoint &pos, char seg_number, TQPainter
TQPointArray pts;
- pt.ry() += (QCOORD)Width/2;
+ pt.ry() += (TQCOORD)Width/2;
if (erase){
@@ -355,7 +355,7 @@ void BW_LED_Number::drawSegment( const TQPoint &pos, char seg_number, TQPainter
p.setPen(g.light());
break;
case 2 :
- pt.rx() += (QCOORD)(Segment_Length);
+ pt.rx() += (TQCOORD)(Segment_Length);
if (erase)
@@ -382,7 +382,7 @@ void BW_LED_Number::drawSegment( const TQPoint &pos, char seg_number, TQPainter
break;
case 3 :
- pt.ry() += (QCOORD)Segment_Length;
+ pt.ry() += (TQCOORD)Segment_Length;
p.setPen(g.background());
@@ -402,7 +402,7 @@ void BW_LED_Number::drawSegment( const TQPoint &pos, char seg_number, TQPainter
break;
case 4 :
- pt.ry() += (QCOORD)(Segment_Length +1);
+ pt.ry() += (TQCOORD)(Segment_Length +1);
p.fillRect(pt.x(), pt.y(), Width , Segment_Length - Width - Width/2 ,brush);
if (erase)
p.setPen(offcolor);
@@ -421,8 +421,8 @@ void BW_LED_Number::drawSegment( const TQPoint &pos, char seg_number, TQPainter
break;
case 5 :
- pt.rx() += (QCOORD)(Segment_Length );
- pt.ry() += (QCOORD)(Segment_Length +1);
+ pt.rx() += (TQCOORD)(Segment_Length );
+ pt.ry() += (TQCOORD)(Segment_Length +1);
p.fillRect(pt.x() - Width +1 ,pt.y(), Width ,
Segment_Length - Width - Width/2 ,brush);
@@ -446,7 +446,7 @@ void BW_LED_Number::drawSegment( const TQPoint &pos, char seg_number, TQPainter
break;
case 6 :
- pt.ry() += (QCOORD)(Segment_Length*2 );
+ pt.ry() += (TQCOORD)(Segment_Length*2 );
p.fillRect(pt.x() + Width ,pt.y() -Width , Segment_Length -2* Width ,
Width ,brush);
@@ -471,13 +471,13 @@ void BW_LED_Number::drawSegment( const TQPoint &pos, char seg_number, TQPainter
break;
case 7 :
- pt.rx() += (QCOORD)(Segment_Length/2);
- pt.ry() += (QCOORD)(Segment_Length*2);
+ pt.rx() += (TQCOORD)(Segment_Length/2);
+ pt.ry() += (TQCOORD)(Segment_Length*2);
p.fillRect(pt.x() ,pt.y() - Width , Width , Width ,brush);
break;
case 8 :
- pt.ry() += (QCOORD)(Segment_Length/2 + Width/2);
- pt.rx() += (QCOORD)(Segment_Length/2 - Width/2 + 1);
+ pt.ry() += (TQCOORD)(Segment_Length/2 + Width/2);
+ pt.rx() += (TQCOORD)(Segment_Length/2 - Width/2 + 1);
if (!show_off_colon && erase) {
p.setBrush(bgcolor);
@@ -494,8 +494,8 @@ void BW_LED_Number::drawSegment( const TQPoint &pos, char seg_number, TQPainter
break;
case 9 :
- pt.ry() += (QCOORD)(3*Segment_Length/2 + Width/2);
- pt.rx() += (QCOORD)(Segment_Length/2 - Width/2 + 1);
+ pt.ry() += (TQCOORD)(3*Segment_Length/2 + Width/2);
+ pt.rx() += (TQCOORD)(Segment_Length/2 - Width/2 + 1);
if (!show_off_colon && erase) {
p.setBrush(bgcolor);
@@ -514,7 +514,7 @@ void BW_LED_Number::drawSegment( const TQPoint &pos, char seg_number, TQPainter
else{
- pt.ry() += (QCOORD)Width/2;
+ pt.ry() += (TQCOORD)Width/2;
switch ( seg_number ) {
case 0 :
@@ -524,37 +524,37 @@ void BW_LED_Number::drawSegment( const TQPoint &pos, char seg_number, TQPainter
p.fillRect(pt.x()+Width,pt.y()- Width , Segment_Length -2* Width, Width ,brush);
break;
case 2 :
- pt.rx() += (QCOORD)(Segment_Length);
+ pt.rx() += (TQCOORD)(Segment_Length);
p.fillRect(pt.x()-Width,pt.y()+ Width/2, Width ,
Segment_Length - Width -Width/2 ,brush);
break;
case 3 :
- pt.ry() += (QCOORD)Segment_Length;
+ pt.ry() += (TQCOORD)Segment_Length;
p.fillRect(pt.x() + Width ,pt.y() - Width, Segment_Length- 2* Width, Width ,brush);
break;
case 4 :
- pt.ry() += (QCOORD)(Segment_Length );
+ pt.ry() += (TQCOORD)(Segment_Length );
p.fillRect(pt.x(), pt.y(), Width , Segment_Length - Width - Width/2 ,brush);
break;
case 5 :
- pt.rx() += (QCOORD)(Segment_Length );
- pt.ry() += (QCOORD)(Segment_Length );
+ pt.rx() += (TQCOORD)(Segment_Length );
+ pt.ry() += (TQCOORD)(Segment_Length );
p.fillRect(pt.x() - Width ,pt.y(), Width ,
Segment_Length - Width - Width/2 ,brush);
break;
case 6 :
- pt.ry() += (QCOORD)(Segment_Length*2);
+ pt.ry() += (TQCOORD)(Segment_Length*2);
p.fillRect(pt.x() + Width ,pt.y() -Width , Segment_Length -2* Width ,
Width ,brush);
break;
case 7 :
- pt.rx() += (QCOORD)(Segment_Length/2);
- pt.ry() += (QCOORD)(Segment_Length*2);
+ pt.rx() += (TQCOORD)(Segment_Length/2);
+ pt.ry() += (TQCOORD)(Segment_Length*2);
p.fillRect(pt.x() ,pt.y() - Width , Width , Width ,brush);
break;
case 8 :
- pt.ry() += (QCOORD)(Segment_Length/2 + Width/2);
- pt.rx() += (QCOORD)(Segment_Length/2 - Width/2 + 1);
+ pt.ry() += (TQCOORD)(Segment_Length/2 + Width/2);
+ pt.rx() += (TQCOORD)(Segment_Length/2 - Width/2 + 1);
if (!show_off_colon && erase) {
p.setBrush(bgcolor);
brush.setColor(bgcolor);
@@ -569,8 +569,8 @@ void BW_LED_Number::drawSegment( const TQPoint &pos, char seg_number, TQPainter
break;
case 9 :
- pt.ry() += (QCOORD)(3*Segment_Length/2 + Width/2);
- pt.rx() += (QCOORD)(Segment_Length/2 - Width/2 + 1);
+ pt.ry() += (TQCOORD)(3*Segment_Length/2 + Width/2);
+ pt.rx() += (TQCOORD)(Segment_Length/2 - Width/2 + 1);
if (!show_off_colon && erase) {
p.setBrush(bgcolor);